@@ -734,7 +734,7 @@ process_page (GtkTreeStore *tree,
 	  g_free (next);
 	  next = NULL;
 	}
-	if (g_str_equal (node, "Top") && prev != NULL) {
+	if (node && g_str_equal (node, "Top") && prev != NULL) {
 	  g_free (prev);
 	  prev = NULL;
 	}
@@ -763,7 +763,7 @@ process_page (GtkTreeStore *tree,
 	}
 	if (prev && g_ascii_strncasecmp (prev, "(dir)", 5))
 	  {
-	    if (strncmp (node, "Top", 3)) {
+	    if (node && strncmp (node, "Top", 3)) {
 	      /* Special case the Top node to always appear first */
 	    } else {
 	      page = node2page (nodes2pages, prev);
@@ -956,7 +956,6 @@ GtkTreeStore
 	nodes2iters = g_hash_table_new_full (g_str_hash, g_str_equal, g_free,
 					     (GDestroyNotify) gtk_tree_iter_free);
 
-	pages = 0;
 	for (ptr = page_list; *ptr != NULL; ptr++)
 	{
 	  if (page_type (*ptr) != PAGE_NODE) continue;
@@ -1171,7 +1170,7 @@ yelp_info_parse_menu (GtkTreeStore *tree, xmlNodePtr *node,
   gchar **split;
   gchar **menuitems;
   gchar *tmp = NULL;
-  xmlNodePtr newnode, menu_node, mholder = NULL;
+  xmlNodePtr newnode, menu_node = NULL, mholder = NULL;
   int i=0;
 
   split = g_strsplit (page_content, "* Menu:", 2);
